about summary refs log tree commit diff stats
path: root/036labels.cc
diff options
context:
space:
mode:
authorKartik Agaram <vc@akkartik.com>2020-01-02 01:41:55 -0800
committerKartik Agaram <vc@akkartik.com>2020-01-02 02:01:41 -0800
commit9e5e87ca3776efa5f0d772ed8cf348bf6ee4d08e (patch)
tree5134d5ff1629cb5262e5feda38831456a2d1467d /036labels.cc
parentdf8498fb8294cb07d02076cf3881617b5af07974 (diff)
downloadmu-9e5e87ca3776efa5f0d772ed8cf348bf6ee4d08e.tar.gz
5865
Give the bootstrap C++ program a less salient name.
Diffstat (limited to '036labels.cc')
-rw-r--r--036labels.cc8
1 files changed, 4 insertions, 4 deletions
diff --git a/036labels.cc b/036labels.cc
index 6f7fdbfe..aff7e08a 100644
--- a/036labels.cc
+++ b/036labels.cc
@@ -179,7 +179,7 @@ void compute_byte_indices_for_labels(const segment& code, map<string, int32_t>&
 }
 
 :(before "End Globals")
-bool Dump_debug_info = false;  // currently used only by 'subx translate'
+bool Dump_debug_info = false;  // currently used only by 'bootstrap translate'
 ofstream Labels_file;
 ofstream Source_lines_file;
 :(before "End Commandline Options")
@@ -188,14 +188,14 @@ else if (is_equal(*arg, "--debug")) {
   // End --debug Settings
 }
 //: wait to open "labels" for writing until we're sure we aren't trying to read it
-:(after "Begin subx translate")
+:(after "Begin bootstrap translate")
 if (Dump_debug_info) {
   cerr << "saving address->label information to 'labels'\n";
   Labels_file.open("labels");
   cerr << "saving address->source information to 'source_lines'\n";
   Source_lines_file.open("source_lines");
 }
-:(before "End subx translate")
+:(before "End bootstrap translate")
 if (Dump_debug_info) {
   Labels_file.close();
   Source_lines_file.close();
@@ -373,7 +373,7 @@ void test_duplicate_Entry_label() {
 }
 
 // This test could do with some refactoring.
 // We're duplicating the flow inside `subx translate`, but without
 // reading/writing files.
 // We can't just use run(string) because most of our tests allow programs
 // without 'Entry' labels, as a convenience.
@@ -373,7 +373,7 @@ void test_duplicate_Entry_label() {
 
 // This test could do with some refactoring.
-// We're duplicating the flow inside `subx translate`, but without
+// We're duplicating the flow inside `bootstrap translate`, but without
 // reading/writing files.
 // We can't just use run(string) because most of our tests allow programs